CREATE SCHEMA Strassennetz

-- Historie:
-- 
-- 09.09.2005 - 1.010 (1.010)
-- Anpassung an ASB-ING, Stand 2004
-- Einfhrung der Ganglinie
-- Schema Arbeitsstelle_an_Strassen erstellt
-- 
-- 29.06.2004 - 1.005 (1.009)
-- Anpassung an ASB-Netzdaten, Stand September 2002
--
-- 03.09.2003 - 1.004 (1.008)
-- Anbindung der Schemata Kostenberechnung und kologie
-- Korrektur der Relation zu Verwaltungsbezirk
-- Korrektur der historischen Gltigkeitsdaten (SQL)
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung des Strassenpunkts
-- gem Dokument N0031
--
-- 12.09.2001 - 1.002 (1.004)
-- Referenzen zum Schema Entwurf angepasst
-- in Folge des nderungsantrags A0006
-- Referenzen zum Schema Unfall angepasst
--
-- 11.12.2000 - 1.001 (1.002)
-- Integration symbolischer Verweise fr
-- Teilbauwerk, oertliche_Zuordnung, oertliche_Zuordnung_SP,
-- Strasse, nicht_nach_ASB_Klass_Strasse, Netzknoten, Nullpunkt,
-- Abschnitt_oder_Ast und Verwaltungsbezirk
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Strassenklasse (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Strassenklasse VALUES ('A','Bundesautobahn')
INSERT INTO Strassenklasse VALUES ('B','Bundesstrae')
INSERT INTO Strassenklasse VALUES ('L','Landesstrae')
INSERT INTO Strassenklasse VALUES ('S','Staatsstrae')
INSERT INTO Strassenklasse VALUES ('K','Kreisstrae')
INSERT INTO Strassenklasse VALUES ('G','Gemeindestrae')

CREATE TABLE Strasse (
   Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Strasse_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Strasse_ID) REFERENCES Strasse_abstrakt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Strassenklasse
      CHAR(1) NOT NULL REFERENCES Strassenklasse,
   Strassennummer
      INTEGER NOT NULL, -- Strassennummer
   CHECK ( ( Strassennummer > 0 ) AND ( Strassennummer <= 9999 ) ),
   Zusatzbuchstabe
      CHAR(1), -- Zusatzbuchstabe
   CHECK ( ( Zusatzbuchstabe >= 'A' ) AND ( Zusatzbuchstabe <= 'Z' ) )
)

CREATE TABLE Strasse__hat_AoA (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Strasse__hat_BAB_Knotennummer (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer
)

CREATE TABLE Strasse__in_Verwaltungsbezirk (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Verwaltungsbezirk_abstrakt
      INTEGER NOT NULL REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE Strasse__enthaelt_Block (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Block
      INTEGER NOT NULL REFERENCES Block
)

CREATE TABLE Strasse__von_Unfallort (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Unfall.Angaben_zum_Unfallort
)

CREATE TABLE Strasse__einm_am_Anfg_v_Unfall (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Unfall.Angaben_zum_Unfallort
)

CREATE TABLE Strasse__einm_am_Ende_v_Unfall (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Angaben_zum_Unfallort
      INTEGER NOT NULL REFERENCES Unfall.Angaben_zum_Unfallort
)

CREATE TABLE Strasse__z_Projektkennz_Kostra (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Projektkennzeichnung_Kostra
      INTEGER NOT NULL REFERENCES Kostenberechnung.Projektkennzeichnung_Kostra
)

CREATE TABLE Strasse__zu_Baumassnahme (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Baumassnahme
      INTEGER NOT NULL REFERENCES Oekologie.Baumassnahme
)

CREATE TABLE Strasse__hat_Arbeitsstelle (
   Strasse
      INTEGER NOT NULL REFERENCES Strasse,
   Arbeitsstelle_an_Strassen
      INTEGER NOT NULL REFERENCES Arbeitsstelle_an_Strassen.Arbeitsstelle_an_Strassen
)

CREATE TABLE Strasse_abstrakt (
   Strasse_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Art_Strasse_abstrakt
)

CREATE TABLE Art_Strasse_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(14) NOT NULL
)

INSERT INTO Art_Strasse_abstrakt VALUES ( 1003, 'Strasse' )
INSERT INTO Art_Strasse_abstrakt VALUES ( 1005, 'Strasse_Symbol' )

CREATE TABLE Strasse_Symbol (
   Strasse_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strasse_Symbol_ID) REFERENCES Strasse_abstrakt,
   Kennung
      VARCHAR(16) NOT NULL
)

CREATE TABLE Knotenart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenart VALUES (1,'plangleich (hhengleich)')
INSERT INTO Knotenart VALUES (2,'planfrei (hhenungleich)')
INSERT INTO Knotenart VALUES (3,'teilplanfrei')
INSERT INTO Knotenart VALUES (0,'fiktiver Netzknoten')

CREATE TABLE Knotenpunktsform (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenpunktsform VALUES (01,'Einmndung oder Kreuzung von 2-streifigen Straen')
INSERT INTO Knotenpunktsform VALUES (02,'Einmndung oder Kreuzung von 2-bahnigen mit 2-streifigen Straen in der Regel mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (03,'Einmndung oder Kreuzung von 2-bahnigen Straen mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (04,'planfreie Kreuzung von 2-streifigen oder 2-bahnigen Straen')
INSERT INTO Knotenpunktsform VALUES (05,'teilplanfreie Kreuzung von 2-streifigen oder 2-bahnigen Straen')
INSERT INTO Knotenpunktsform VALUES (06,'Kreuzung 2-streifiger Straen als Versatz')
INSERT INTO Knotenpunktsform VALUES (07,'Aufgeweitete Einmndung oder Kreuzung mit mindestens einer 2-bahnigen Strae')
INSERT INTO Knotenpunktsform VALUES (08,'kleiner Kreisverkehrsplatz, d < 30 m')
INSERT INTO Knotenpunktsform VALUES (09,'groer Kreisverkehrsplatz, d > 30 m')
INSERT INTO Knotenpunktsform VALUES (11,'Einmndung oder Kreuzung von 2-streifigen Straen mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (12,'Einmndung oder Kreuzung von 2-bahnigen mit 2-streifigen Straen mit Lichtsignalanlage')
INSERT INTO Knotenpunktsform VALUES (13,'planfreie Kreuzung mit Lichtsignalanlagen')
INSERT INTO Knotenpunktsform VALUES (14,'Kreuzung 2-streifiger Straen als Versatz mit Lichtsignalanlage')

CREATE TABLE Knotenpunktsystem (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Knotenpunktsystem VALUES (01,'Trompete')
INSERT INTO Knotenpunktsystem VALUES (02,'Birne')
INSERT INTO Knotenpunktsystem VALUES (03,'Dreieck mit 3 zweigeschossigen Bauwerken')
INSERT INTO Knotenpunktsystem VALUES (04,'Dreieck mit 1 dreigeschossigen Bauwerk')
INSERT INTO Knotenpunktsystem VALUES (05,'Kleeblatt')
INSERT INTO Knotenpunktsystem VALUES (06,'Kleeblatt, abgewandelt mit halbdirekter Fhrung eines Linksabbiegestromes')
INSERT INTO Knotenpunktsystem VALUES (07,'Kleeblatt, abgewandelt mit zgiger halbdirekter Fhrung eines Linksabbiegestromes')
INSERT INTO Knotenpunktsystem VALUES (08,'halbes Kleeblatt')
INSERT INTO Knotenpunktsystem VALUES (09,'halbes Kleeblatt, asymmetrisch')
INSERT INTO Knotenpunktsystem VALUES (10,'halbes Kleeblatt, asymmetrisch mit innen- und hintereinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (11,'halbes Kleeblatt, asymmetrisch mit innen- und nebeneinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (12,'halbes Kleeblatt, symmetrisch')
INSERT INTO Knotenpunktsystem VALUES (13,'Raute mit innen- und hintereinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (14,'Raute mit innen- und nebeneinanderliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (15,'Raute mit aufgeweiteter Kreuzung')
INSERT INTO Knotenpunktsystem VALUES (16,'Raute mit auenliegenden Linksabbiegespuren')
INSERT INTO Knotenpunktsystem VALUES (17,'Sondersystem')

CREATE TABLE Netzknoten (
   Netzknoten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Netzknoten_ID) REFERENCES Netzknoten_abstrakt,
   Netzknoten_ext
      CHAR(7),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Numerierungsbezirk
      CHAR(4) NOT NULL, -- TK25_Blattnummer
   Nummer
      CHAR(3) NOT NULL, -- lfd_NK_Nummer
   Knotenart
      INTEGER REFERENCES Knotenart,
   Knotenname
      VARCHAR(60),
   Knotenpunktsform
      INTEGER REFERENCES Knotenpunktsform,
   Knotenpunktsystem
      INTEGER REFERENCES Knotenpunktsystem
)

CREATE TABLE NK__hat_BAB_Knotennummer (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer
)

CREATE TABLE Netzknoten__hat_Nullpunkt (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Netzkn__enthaelt_Strassel (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Strassenelement_abstrakt
      INTEGER NOT NULL REFERENCES Strassenelement_abstrakt
)

CREATE TABLE Netzkn__hat_Netzknskizze (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Dokument_abstrakt
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Dokument_abstrakt
)

CREATE TABLE Netzknoten__hat_Einmessskizze (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Dokument_abstrakt
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Dokument_abstrakt
)

CREATE TABLE Netzknoten__Beginn_von (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES Dynamische_Beschilderung.WW_Wirkungsbereiche
)

CREATE TABLE Netzknoten__Ende_von (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   WW_Wirkungsbereiche
      INTEGER NOT NULL REFERENCES Dynamische_Beschilderung.WW_Wirkungsbereiche
)

CREATE TABLE Netzknoten__auf_Trasse (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Trasse
      INTEGER NOT NULL REFERENCES Entwurf.Trasse
)

CREATE TABLE Netzknoten__hat_Wegweiser (
   Netzknoten
      INTEGER NOT NULL REFERENCES Netzknoten,
   Wegweiser
      INTEGER NOT NULL REFERENCES Statische_Beschilderung.Wegweiser
)

CREATE TABLE Netzknoten_abstrakt (
   Netzknoten_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Art_Netzknoten_abstrakt
)

CREATE TABLE Art_Netzknoten_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(17) NOT NULL
)

INSERT INTO Art_Netzknoten_abstrakt VALUES ( 1011, 'Netzknoten' )
INSERT INTO Art_Netzknoten_abstrakt VALUES ( 1013, 'Netzknoten_Symbol' )

CREATE TABLE Netzknoten_Symbol (
   Netzknoten_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzknoten_Symbol_ID) REFERENCES Netzknoten_abstrakt,
   Kennung
      CHAR(7) NOT NULL
)

CREATE TABLE TK25Blatt (
   TK25Blatt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nummer
      CHAR(4) NOT NULL, -- TK25_Blattnummer
   Bezeichnung
      VARCHAR(30),
   hat_Bereich
      INTEGER REFERENCES Geometrieschema.BoundingBox
)

CREATE TABLE Nummernintervall (
   Nummernintervall_ID
      INTEGER NOT NULL PRIMARY KEY,
   von
      CHAR(3) NOT NULL, -- lfd_NK_Nummer
   bis
      CHAR(3) NOT NULL, -- lfd_NK_Nummer
   gehoert_zu_TK25Blatt
      INTEGER NOT NULL REFERENCES TK25Blatt
)

CREATE TABLE Nummernintervall__fuer_Land (
   Nummernintervall
      INTEGER NOT NULL REFERENCES Nummernintervall,
   Verwaltungsbezirk_abstrakt
      INTEGER NOT NULL REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE BAB_Knotennummer (
   BAB_Knotennummer_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (BAB_Knotennummer_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (BAB_Knotennummer_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Knotennummer
      INTEGER NOT NULL,
   Buchstabe
      CHAR(1)
)

CREATE TABLE BAB_Knotennummer__auf_Strasse (
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE BAB_Knotennummer__von_NK (
   BAB_Knotennummer
      INTEGER NOT NULL REFERENCES BAB_Knotennummer,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Stadium (
   Stadium_ID
      INTEGER NOT NULL PRIMARY KEY,
   unter_Verkehr
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   Stadium
      CHAR(3) NOT NULL REFERENCES Tab_Stadium,
   Verkehrsfreigabe
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Verkehrsfreigabe LIKE '__.__.____' )
)

CREATE TABLE Tab_Stadium (
   Kennung
      CHAR(3) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Stadium VALUES ('VP','Vorplanung hat begonnen')
INSERT INTO Tab_Stadium VALUES ('UVA','Umweltvertrglichkeitsstudie bzw. Variantenuntersuchung hat begonnen')
INSERT INTO Tab_Stadium VALUES ('UVE','Umweltvertrglichkeitsstudie bzw. Variantenuntersuchung ist abgeschlossen')
INSERT INTO Tab_Stadium VALUES ('LBV','Unterlagen fr Linienbestimmung/Trassenfestlegung werden aufgestellt')
INSERT INTO Tab_Stadium VALUES ('LBE','Linie bestimmt/Trassenfhrung festgelegt')
INSERT INTO Tab_Stadium VALUES ('VE','Vorentwurf hat begonnen')
INSERT INTO Tab_Stadium VALUES ('VEG','Vorentwurf genehmigt')
INSERT INTO Tab_Stadium VALUES ('PA','Planfeststellungsverfahren beantragt')
INSERT INTO Tab_Stadium VALUES ('PB','Planfeststellungsbeschluss ergangen')
INSERT INTO Tab_Stadium VALUES ('PU','Planfeststellungsbeschluss bestandskrftig')
INSERT INTO Tab_Stadium VALUES ('BAU','Durchfhrung der Bauarbeiten begonnen')
INSERT INTO Tab_Stadium VALUES ('VFV','Verkehrsfreigabe der Gesamtstrecke der Verkehrseinheit ist erfolgt')
INSERT INTO Tab_Stadium VALUES ('EPL','Erneuerung/Ersatzneubau in Planung')
INSERT INTO Tab_Stadium VALUES ('EAU','Erneuerung/Ersatzneubau in Ausfhrung')
INSERT INTO Tab_Stadium VALUES ('IPL','Instandsetzung in Planung')
INSERT INTO Tab_Stadium VALUES ('IAU','Instandsetzung in Ausfhrung')

CREATE TABLE Abschnitt_oder_Ast (
   Abschnitt_oder_Ast_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Abschnitt_oder_Ast_ID) REFERENCES Abschnitt_oder_Ast_abstrakt,
   Abschnitt_oder_Ast_ext
      CHAR(16),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Art_Abschnitt_oder_Ast,
   Laenge
      REAL, -- Kilometer
   Herkunft_Laenge
      INTEGER REFERENCES Herkunft_Laenge,
   Stadium
      INTEGER REFERENCES Stadium,
   Betriebsmerkmal
      INTEGER REFERENCES Betriebsmerkmal,
   Abschnitts_Astnummer
      VARCHAR(7),
   Abschnitts_Astbezeichnung
      VARCHAR(60),
   Seitenarm
      INTEGER REFERENCES Logical_Types.Boolean, -- Abschnitt
   getrennt_verlaufende_Fahrbahn
      INTEGER REFERENCES Zweig_der_Trennung, -- Abschnitt
   Abschnittsfolgenummer
      VARCHAR(4), -- Abschnitt
   Funktion
      INTEGER REFERENCES Funktion_des_Astes -- Ast
)

CREATE TABLE Art_Abschnitt_oder_Ast (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(9) NOT NULL
)

INSERT INTO Art_Abschnitt_oder_Ast VALUES ( 1019, 'Abschnitt' )
INSERT INTO Art_Abschnitt_oder_Ast VALUES ( 1020, 'Ast' )

CREATE TABLE AoA__beginnt_bei_Nullpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE AoA__endet_bei_Nullpunkt (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE AoA__gehoert_zu_Strasse (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE AoA__enthaelt_Strassel (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Strassenelement_abstrakt
      INTEGER NOT NULL REFERENCES Strassenelement_abstrakt
)

CREATE TABLE Abschnitt_oder_Ast__z_Baumassn (
   Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast,
   Baumassnahme
      INTEGER NOT NULL REFERENCES Oekologie.Baumassnahme
)

CREATE TABLE Herkunft_Laenge (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Herkunft_Laenge VALUES (1,'vor Ort gemessen')
INSERT INTO Herkunft_Laenge VALUES (2,'Bauunterlagen')
INSERT INTO Herkunft_Laenge VALUES (3,'Planungsunterlagen')
INSERT INTO Herkunft_Laenge VALUES (4,'aus der Digitalisierung')

CREATE TABLE Abschnitt_oder_Ast_abstrakt (
   Abschnitt_oder_Ast_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Abschnitt_oder_Ast_abstr
      INTEGER NOT NULL REFERENCES Art_Abschnitt_oder_Ast_abstr
)

CREATE TABLE Art_Abschnitt_oder_Ast_abstr (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(25) NOT NULL
)

INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES ( 1018, 'Abschnitt_oder_Ast_Symbol' )
INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES ( 1019, 'Abschnitt' )
INSERT INTO Art_Abschnitt_oder_Ast_abstr VALUES ( 1020, 'Ast' )

CREATE TABLE Abschnitt_oder_Ast_Symbol (
   Abschnitt_oder_Ast_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abschnitt_oder_Ast_Symbol_ID) REFERENCES Abschnitt_oder_Ast_abstrakt,
   Kennung
      VARCHAR(16) NOT NULL
)

CREATE TABLE Zweig_der_Trennung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zweig_der_Trennung VALUES (1,'getrennt verlaufende Fahrbahn, Zweig 1 (in Stationierungsrichtung befahren)')
INSERT INTO Zweig_der_Trennung VALUES (2,'getrennt verlaufende Fahrbahn, Zweig 2 (gegen Stationierungsrichtung befahren)')

CREATE TABLE Funktion_des_Astes (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Funktion_des_Astes VALUES (1,'Einfahrt / Ausfahrt')
INSERT INTO Funktion_des_Astes VALUES (2,'Parallelfahrbahn (baulich getrennt)')
INSERT INTO Funktion_des_Astes VALUES (3,'Fahrbahn des Kreisverkehrs')

CREATE TABLE Betriebsmerkmal (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Betriebsmerkmal VALUES (1,'durchgehende Strecke')
INSERT INTO Betriebsmerkmal VALUES (2,'Verbindungsrampe')

CREATE TABLE Nullpunkt (
   Nullpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Nullpunkt_ID) REFERENCES Nullpunkt_abstrakt,
   Nullpunkt_ext
      CHAR(8),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Zusatz
      CHAR(1) NOT NULL, -- Nullpunktkennung
   CHECK ( ( ( Zusatz >= 'A' AND Zusatz <= 'Z' ) OR ( Zusatz = ' ' ) ) ),
   Nullpunktart
      INTEGER NOT NULL REFERENCES Nullpunktart
)

CREATE TABLE Nullpunkt__in_Netzknoten (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Nullpunkt__Beginn_von_AoA (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Nullpunkt__Ende_von_AoA (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Nullpunkt__hat_Nullpunktsort (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Nullpunktsort
      INTEGER NOT NULL REFERENCES Nullpunktsort
)

CREATE TABLE Nullpunkt__hat_Strassenelement (
   Nullpunkt
      INTEGER NOT NULL REFERENCES Nullpunkt,
   Strassenelement_abstrakt
      INTEGER NOT NULL REFERENCES Strassenelement_abstrakt
)

CREATE TABLE Nullpunktart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Nullpunktart VALUES (1,'zentraler Nullpunkt')
INSERT INTO Nullpunktart VALUES (2,'Nullpunkt')
INSERT INTO Nullpunktart VALUES (0,'fiktiver Nullpunkt')

CREATE TABLE Nullpunkt_abstrakt (
   Nullpunkt_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Art_Nullpunkt_abstrakt
)

CREATE TABLE Art_Nullpunkt_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(16) NOT NULL
)

INSERT INTO Art_Nullpunkt_abstrakt VALUES ( 1022, 'Nullpunkt' )
INSERT INTO Art_Nullpunkt_abstrakt VALUES ( 1024, 'Nullpunkt_Symbol' )

CREATE TABLE Nullpunkt_Symbol (
   Nullpunkt_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nullpunkt_Symbol_ID) REFERENCES Nullpunkt_abstrakt,
   Kennung
      CHAR(8) NOT NULL
)

CREATE TABLE Bezugsrichtung (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Bezugsrichtung VALUES ('B','beide Richtungen')
INSERT INTO Bezugsrichtung VALUES ('R','in Stationierungsrichtung')
INSERT INTO Bezugsrichtung VALUES ('G','gegen Stationierungsrichtung')

CREATE TABLE Punktobjekt (
   Punktobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Punktobjekt
      INTEGER NOT NULL REFERENCES Art_Punktobjekt,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Kilometer
   Abstand_zur_Bestandsachse
      REAL, -- Meter
   Abstand_zur_Fahrbahnoberkante
      REAL -- Meter
)

CREATE TABLE Art_Punktobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Punktobjekt VALUES ( 1032, 'oertliche_Zuordnung_SP' )
INSERT INTO Art_Punktobjekt VALUES ( 1058, 'Kilometrierung' )

INSERT INTO Art_Punktobjekt VALUES ( 4002, 'Schichtbegrenzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4007, 'Streifenbegrenzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4024, 'Gewaesserkreuzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4025, 'Bahnkreuzung' )
INSERT INTO Art_Punktobjekt VALUES ( 4028, 'Kreuzung_Strasse_Weg' )
INSERT INTO Art_Punktobjekt VALUES ( 4034, 'Durchlass' )
INSERT INTO Art_Punktobjekt VALUES ( 7008, 'Sachverhalt' )
INSERT INTO Art_Punktobjekt VALUES ( 7004, 'Teilbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7014, 'Bruecke' )
INSERT INTO Art_Punktobjekt VALUES ( 7015, 'Verkehrszeichenbruecke' )
INSERT INTO Art_Punktobjekt VALUES ( 7016, 'Tunnel_Trogbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7017, 'Laermschutzbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7018, 'Stuetzbauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 7019, 'sonstiges_Bauwerk' )
INSERT INTO Art_Punktobjekt VALUES ( 13023, 'Ganglinie_Punktobjekt' )
INSERT INTO Art_Punktobjekt VALUES ( 19005, 'Unfallort_Strassenpunkt' )
INSERT INTO Art_Punktobjekt VALUES ( 20012, 'Wirkungsbereich_SP' )
INSERT INTO Art_Punktobjekt VALUES ( 20047, 'Aufstellvorrichtung' )
INSERT INTO Art_Punktobjekt VALUES ( 20055, 'Anordnung_des_Messsystems' )
INSERT INTO Art_Punktobjekt VALUES ( 21014, 'Standort' )
INSERT INTO Art_Punktobjekt VALUES ( 21031, 'stat_verkehrsreg_Beschilderung' )
INSERT INTO Art_Punktobjekt VALUES ( 21042, 'Position' )
INSERT INTO Art_Punktobjekt VALUES ( 32016, 'Standortbeschreibung_Baum' )
INSERT INTO Art_Punktobjekt VALUES ( 34017, 'Tierwechsel' )
INSERT INTO Art_Punktobjekt VALUES ( 34019, 'Kreuzung_sonst_Verkehrsanl' )

CREATE TABLE Punktobjekt_stat (
   Punktobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Punktobjekt_stat_ID) REFERENCES Punktobjekt,
   Art_Punktobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Punktobjekt_stat
)

CREATE TABLE Art_Punktobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Punktobjekt_stat VALUES ( 1032, 'oertliche_Zuordnung_SP' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 7008, 'Sachverhalt' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 13023, 'Ganglinie_Punktobjekt' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 19005, 'Unfallort_Strassenpunkt' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 20012, 'Wirkungsbereich_SP' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 20055, 'Anordnung_des_Messsystems' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 21014, 'Standort' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 21031, 'stat_verkehrsreg_Beschilderung' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 21042, 'Position' )
INSERT INTO Art_Punktobjekt_stat VALUES ( 32016, 'Standortbeschreibung_Baum' )

CREATE TABLE Punktobjekt_hist (
   Punktobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Punktobjekt_hist_ID) REFERENCES Punktobjekt,
   FOREIGN KEY (Punktobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Punktobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Punktobjekt_hist
)

CREATE TABLE Art_Punktobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(26) NOT NULL
)

INSERT INTO Art_Punktobjekt_hist VALUES ( 1058, 'Kilometrierung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4002, 'Schichtbegrenzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4007, 'Streifenbegrenzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4024, 'Gewaesserkreuzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4025, 'Bahnkreuzung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4028, 'Kreuzung_Strasse_Weg' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 4034, 'Durchlass' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7004, 'Teilbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7014, 'Bruecke' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7015, 'Verkehrszeichenbruecke' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7016, 'Tunnel_Trogbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7017, 'Laermschutzbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7018, 'Stuetzbauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 7019, 'sonstiges_Bauwerk' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 20047, 'Aufstellvorrichtung' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 34017, 'Tierwechsel' )
INSERT INTO Art_Punktobjekt_hist VALUES ( 34019, 'Kreuzung_sonst_Verkehrsanl' )

CREATE TABLE oertliche_Zuordnung (
   oertliche_Zuordnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   liegt_auf_Strassenpunkt
      INTEGER REFERENCES oertliche_Zuordnung_SP,
   liegt_auf_nicht_klass_Strasse
      INTEGER REFERENCES nicht_nach_ASB_klass_Strasse,
   CHECK ( ( ( liegt_auf_Strassenpunkt IS NOT NULL ) OR ( liegt_auf_nicht_klass_Strasse IS NOT NULL ) ) AND ( ( liegt_auf_Strassenpunkt IS NULL ) OR ( liegt_auf_nicht_klass_Strasse IS NULL ) ) )
)

CREATE TABLE oertliche_Zuordnung_SP (
   oertliche_Zuordnung_SP_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_SP_ID) REFERENCES Punktobjekt_stat
)

CREATE TABLE nicht_nach_ASB_klass_Strasse (
   nicht_n_ASB_klass_Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Strassenklasse
      VARCHAR(50) NOT NULL,
   Nummer
      INTEGER NOT NULL,
   Lage
      VARCHAR(28) NOT NULL
)

CREATE TABLE Nullpunktsort (
   Nullpunktsort_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Nullpunktsort_ID) REFERENCES Administration.ASB_Objekt,
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station
      REAL NOT NULL, -- Kilometer
   Abstand_zur_Bestandsachse
      REAL, -- Meter
   Abstand_zur_Fahrbahnoberkante
      REAL -- Meter
)

CREATE TABLE Nullpunktsort__bei_Nullpunkt (
   Nullpunktsort
      INTEGER NOT NULL REFERENCES Nullpunktsort,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Punktobjekt_o_Bereichsobjekt (
   Punktobjekt_o_Bereichsobj_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Punktobj_o_Bereichsobj
      INTEGER NOT NULL REFERENCES Art_Punktobj_o_Bereichsobj,
   Station
      REAL, -- Kilometer
   Abstand_zur_Bestandsachse
      REAL, -- Meter
   Abstand_zur_Fahrbahnoberkante
      REAL, -- Meter
   auf_Abschnitt_oder_Ast
      INTEGER REFERENCES Abschnitt_oder_Ast_abstrakt,
   ist_Bereichsobjekt
      INTEGER REFERENCES Netzbereich
)

CREATE TABLE Art_Punktobj_o_Bereichsobj (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(28) NOT NULL
)

INSERT INTO Art_Punktobj_o_Bereichsobj VALUES ( 11001, 'Beschilderung_Lichtsignalanl' )
INSERT INTO Art_Punktobj_o_Bereichsobj VALUES ( 11002, 'Fahrbahnmarkierungen' )
INSERT INTO Art_Punktobj_o_Bereichsobj VALUES ( 11003, 'Schutz_und_Leiteinrichtungen' )

CREATE TABLE Netzbereichskomponente (
   Netzbereichskomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Netzbereichskomponente
      INTEGER NOT NULL REFERENCES Art_Netzbereichskomponente
)

CREATE TABLE Art_Netzbereichskomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(16) NOT NULL
)

INSERT INTO Art_Netzbereichskomponente VALUES ( 1039, 'Netzbereich' )
INSERT INTO Art_Netzbereichskomponente VALUES ( 1050, 'Teilabschnitt_NB' )
INSERT INTO Art_Netzbereichskomponente VALUES ( 1051, 'Strecke' )
INSERT INTO Art_Netzbereichskomponente VALUES ( 1052, 'Strecke_SO' )

CREATE TABLE Netzbereich (
   Netzbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Netzbereich_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Netzbereich_ID) REFERENCES Netzbereichskomponente,
   FOREIGN KEY (Netzbereich_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Netzbrch__enthaelt_Komponenten (
   Netzbereich
      INTEGER NOT NULL REFERENCES Netzbereich,
   Netzbereichskomponente
      INTEGER REFERENCES Netzbereichskomponente,
   auf_Abschnitt_oder_Ast
      INTEGER REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL, -- Kilometer
   Abstand_zur_Bestandsachse_1
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_1
      REAL, -- Meter
   Station_2
      REAL, -- Kilometer
   Abstand_zur_Bestandsachse_2
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_2
      REAL -- Meter
)

CREATE TABLE Bereichsobjekt (
   Bereichsobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Bereichsobjekt
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt
)

CREATE TABLE Art_Bereichsobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Bereichsobjekt VALUES ( 1071, 'Teilnetz_ASB' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2005, 'Bundesland' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2006, 'Regierungsbezirk' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2007, 'Kreis_kreisfreie_Stadt' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2009, 'Gemeindebezirk' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2012, 'Ortsteil' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2016, 'Land_Ministerium' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2017, 'Regierungspraesidium_Landesamt' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2018, 'Amt' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2019, 'Meisterei' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2020, 'Kreisverwaltung' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2021, 'Gemeindeverwaltung' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2023, 'UI_Vereinbarung' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2025, 'Baulast' )
INSERT INTO Art_Bereichsobjekt VALUES ( 2036, 'Staat' )
INSERT INTO Art_Bereichsobjekt VALUES ( 4020, 'Schutzzone' )
INSERT INTO Art_Bereichsobjekt VALUES ( 13024, 'Ganglinie_Bereichsobjekt' )

CREATE TABLE Bereichsobj__hat_Netzbereich (
   Bereichsobjekt
      INTEGER NOT NULL REFERENCES Bereichsobjekt,
   Netzbereich
      INTEGER NOT NULL REFERENCES Netzbereich
)

CREATE TABLE Bereichsobjekt_stat (
   Bereichsobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bereichsobjekt_stat_ID) REFERENCES Bereichsobjekt,
   Art_Bereichsobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt_stat
)

CREATE TABLE Art_Bereichsobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(24) NOT NULL
)

INSERT INTO Art_Bereichsobjekt_stat VALUES (1,'Ganglinie_Bereichsobjekt')

CREATE TABLE Bereichsobjekt_hist (
   Bereichsobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bereichsobjekt_hist_ID) REFERENCES Bereichsobjekt,
   FOREIGN KEY (Bereichsobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Bereichsobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Bereichsobjekt_hist
)

CREATE TABLE Art_Bereichsobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Bereichsobjekt_hist VALUES ( 1071, 'Teilnetz_ASB' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2005, 'Bundesland' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2006, 'Regierungsbezirk' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2007, 'Kreis_kreisfreie_Stadt' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2009, 'Gemeindebezirk' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2012, 'Ortsteil' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2016, 'Land_Ministerium' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2017, 'Regierungspraesidium_Landesamt' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2018, 'Amt' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2019, 'Meisterei' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2020, 'Kreisverwaltung' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2021, 'Gemeindeverwaltung' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2023, 'UI_Vereinbarung' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2025, 'Baulast' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 2036, 'Staat' )
INSERT INTO Art_Bereichsobjekt_hist VALUES ( 4020, 'Schutzzone' )

CREATE TABLE Teilnetz_ASB (
   Teilnetz_ASB_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilnetz_ASB_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Teilnetz_ASB_ID) REFERENCES Bereichsobjekt_hist,
   Teilnetzklasse
      INTEGER NOT NULL REFERENCES Teilnetzklasse,
   Name_in_Teilnetz
      VARCHAR(60) NOT NULL,
   Winterdienstprioritaet
      INTEGER REFERENCES Winterdienstprioritaet,
   Richtung
      CHAR(1) REFERENCES Bezugsrichtung
)

CREATE TABLE Teilnetzklasse (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Teilnetzklasse VALUES (1,'Europastrae')
INSERT INTO Teilnetzklasse VALUES (2,'Kraftfahrstrae')
INSERT INTO Teilnetzklasse VALUES (3,'Planungsnetz')
INSERT INTO Teilnetzklasse VALUES (4,'Regionales Netz')
INSERT INTO Teilnetzklasse VALUES (5,'Touristische Strae')
INSERT INTO Teilnetzklasse VALUES (6,'Bedarfsumleitung')
INSERT INTO Teilnetzklasse VALUES (7,'Fahrverbot (fr Gefahrgut)')
INSERT INTO Teilnetzklasse VALUES (8,'Weie Strecken (kein Winterdienst)')
INSERT INTO Teilnetzklasse VALUES (9,'Hochwasser gefhrdete Strecken')
INSERT INTO Teilnetzklasse VALUES (10,'Hhenklasse')
INSERT INTO Teilnetzklasse VALUES (11,'Winterdienstprioritt')
INSERT INTO Teilnetzklasse VALUES (12,'MilGeo-Netze')

CREATE TABLE Winterdienstprioritaet (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Winterdienstprioritaet VALUES (1,'hohe Winterdienstprioritt')
INSERT INTO Winterdienstprioritaet VALUES (2,'mittlere Winterdienstprioritt')
INSERT INTO Winterdienstprioritaet VALUES (3,'geringe Winterdienstprioritt')

CREATE TABLE Streckenobjekt (
   Streckenobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Streckenobjekt
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt
)

CREATE TABLE Art_Streckenobjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(38) NOT NULL
)

INSERT INTO Art_Streckenobjekt VALUES ( 1060, 'Block' )
INSERT INTO Art_Streckenobjekt VALUES ( 1065, 'Entwurfselement_Kreisbogen' )
INSERT INTO Art_Streckenobjekt VALUES ( 1066, 'Entwurfselement_Klothoide' )
INSERT INTO Art_Streckenobjekt VALUES ( 1067, 'Entwurfselement_Gerade' )
INSERT INTO Art_Streckenobjekt VALUES ( 1072, 'Strassel_auf_Abschn_o_Ast' )
INSERT INTO Art_Streckenobjekt VALUES ( 2030, 'OD_FS' )
INSERT INTO Art_Streckenobjekt VALUES ( 2032, 'Widmung' )
INSERT INTO Art_Streckenobjekt VALUES ( 3003, 'Anzahl_Fahrstreifen' )
INSERT INTO Art_Streckenobjekt VALUES ( 3005, 'Insassen_min_Anzahl' )
INSERT INTO Art_Streckenobjekt VALUES ( 3006, 'Ueberholverbot' )
INSERT INTO Art_Streckenobjekt VALUES ( 3007, 'max_Hoehe' )
INSERT INTO Art_Streckenobjekt VALUES ( 3008, 'max_Breite' )
INSERT INTO Art_Streckenobjekt VALUES ( 3009, 'max_Laenge' )
INSERT INTO Art_Streckenobjekt VALUES ( 3010, 'max_Gewicht' )
INSERT INTO Art_Streckenobjekt VALUES ( 3011, 'max_Achsgewicht' )
INSERT INTO Art_Streckenobjekt VALUES ( 3012, 'max_Geschwindigkeit' )
INSERT INTO Art_Streckenobjekt VALUES ( 3013, 'Zugangsbeschraenkung' )
INSERT INTO Art_Streckenobjekt VALUES ( 3014, 'Gesperrt' )
INSERT INTO Art_Streckenobjekt VALUES ( 3016, 'Fkt_d_Verb_im_Knotenpktber' )
INSERT INTO Art_Streckenobjekt VALUES ( 3018, 'Bergpass' )
INSERT INTO Art_Streckenobjekt VALUES ( 3019, 'Verkehrsbedeutung' )
INSERT INTO Art_Streckenobjekt VALUES ( 3020, 'Spur_fuer_Rettungsfahrzeuge' )
INSERT INTO Art_Streckenobjekt VALUES ( 3021, 'Strassenfunktion' )
INSERT INTO Art_Streckenobjekt VALUES ( 3022, 'Aussichtswert' )
INSERT INTO Art_Streckenobjekt VALUES ( 3023, 'Staugefahr' )
INSERT INTO Art_Streckenobjekt VALUES ( 3024, 'gebuehrenpflichtig' )
INSERT INTO Art_Streckenobjekt VALUES ( 3025, 'Durchschnittsgeschwindigkeit' )
INSERT INTO Art_Streckenobjekt VALUES ( 4001, 'Schicht' )
INSERT INTO Art_Streckenobjekt VALUES ( 4005, 'Querschnittstreifen' )
INSERT INTO Art_Streckenobjekt VALUES ( 4008, 'Bauklasse_Oberbau' )
INSERT INTO Art_Streckenobjekt VALUES ( 4009, 'Bauweise_Oberbau' )
INSERT INTO Art_Streckenobjekt VALUES ( 4010, 'Regelquerschnitt' )
INSERT INTO Art_Streckenobjekt VALUES ( 4011, 'Bahnigkeit' )
INSERT INTO Art_Streckenobjekt VALUES ( 4013, 'Fahrbahnlaengsneigung' )
INSERT INTO Art_Streckenobjekt VALUES ( 4014, 'Fahrbahnquerneigung' )
INSERT INTO Art_Streckenobjekt VALUES ( 4015, 'Fahrbahntrennung' )
INSERT INTO Art_Streckenobjekt VALUES ( 4016, 'Trassenbreite' )
INSERT INTO Art_Streckenobjekt VALUES ( 4017, 'Fahrbahnbreite' )
INSERT INTO Art_Streckenobjekt VALUES ( 4018, 'Fussweg' )
INSERT INTO Art_Streckenobjekt VALUES ( 4019, 'Radweg' )
INSERT INTO Art_Streckenobjekt VALUES ( 4021, 'Hindernis' )
INSERT INTO Art_Streckenobjekt VALUES ( 5003, 'Nebenanlage' )
INSERT INTO Art_Streckenobjekt VALUES ( 5005, 'Rastanlage_nicht_bew' )
INSERT INTO Art_Streckenobjekt VALUES ( 5006, 'Rastanlage_bew' )
INSERT INTO Art_Streckenobjekt VALUES ( 5007, 'Nebenbetrieb' )
INSERT INTO Art_Streckenobjekt VALUES ( 5008, 'Leitung' )
INSERT INTO Art_Streckenobjekt VALUES ( 5012, 'Markierung' )
INSERT INTO Art_Streckenobjekt VALUES ( 5014, 'Schutzplanke' )
INSERT INTO Art_Streckenobjekt VALUES ( 5015, 'Strassenentwaesserung' )
INSERT INTO Art_Streckenobjekt VALUES ( 6001, 'ZEB_Objekt' )
INSERT INTO Art_Streckenobjekt VALUES ( 7004, 'Teilbauwerk' )
INSERT INTO Art_Streckenobjekt VALUES ( 7008, 'Sachverhalt' )
INSERT INTO Art_Streckenobjekt VALUES ( 7014, 'Bruecke' )
INSERT INTO Art_Streckenobjekt VALUES ( 7015, 'Verkehrszeichenbruecke' )
INSERT INTO Art_Streckenobjekt VALUES ( 7016, 'Tunnel_Trogbauwerk' )
INSERT INTO Art_Streckenobjekt VALUES ( 7017, 'Laermschutzbauwerk' )
INSERT INTO Art_Streckenobjekt VALUES ( 7018, 'Stuetzbauwerk' )
INSERT INTO Art_Streckenobjekt VALUES ( 7019, 'sonstiges_Bauwerk' )
INSERT INTO Art_Streckenobjekt VALUES ( 12001, 'automat_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt VALUES ( 12015, 'abgeleitete_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt VALUES ( 17006, 'raeuml_Gueltigkeitsbereich_MZ' )
INSERT INTO Art_Streckenobjekt VALUES ( 20010, 'SB_Wirkungsbereiche' )
INSERT INTO Art_Streckenobjekt VALUES ( 21038, 'raeumlicher_Gueltigkeitsber' )
INSERT INTO Art_Streckenobjekt VALUES ( 35001, 'Arbeitsstelle_an_Strassen' )
INSERT INTO Art_Streckenobjekt VALUES ( 35002, 'verkehrliche_Angaben_Arbeitsst' )
INSERT INTO Art_Streckenobjekt VALUES ( 35003, 'Umleitung_Strecke' )

CREATE TABLE Streckenobjekt__hat_Strecke (
   Streckenobjekt
      INTEGER NOT NULL REFERENCES Streckenobjekt,
   Strecke
      INTEGER NOT NULL REFERENCES Strecke
)

CREATE TABLE Streckenobjekt_stat (
   Streckenobjekt_stat_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streckenobjekt_stat_ID) REFERENCES Streckenobjekt,
   Art_Streckenobjekt_stat
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt_stat
)

CREATE TABLE Art_Streckenobjekt_stat (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Streckenobjekt_stat VALUES ( 1065, 'Entwurfselement_Kreisbogen' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 1066, 'Entwurfselement_Klothoide' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 1067, 'Entwurfselement_Gerade' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3003, 'Anzahl_Fahrstreifen' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3005, 'Insassen_min_Anzahl' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3006, 'Ueberholverbot' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3007, 'max_Hoehe' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3008, 'max_Breite' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3009, 'max_Laenge' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3010, 'max_Gewicht' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3011, 'max_Achsgewicht' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3012, 'max_Geschwindigkeit' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3013, 'Zugangsbeschraenkung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3014, 'Gesperrt' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3016, 'Fkt_d_Verb_im_Knotenpktber' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3018, 'Bergpass' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3019, 'Verkehrsbedeutung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3020, 'Spur_fuer_Rettungsfahrzeuge' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3021, 'Strassenfunktion' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3022, 'Aussichtswert' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3023, 'Staugefahr' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3024, 'gebuehrenpflichtig' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 3025, 'Durchschnittsgeschwindigkeit' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4015, 'Fahrbahntrennung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4016, 'Trassenbreite' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4017, 'Fahrbahnbreite' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4018, 'Fussweg' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 4019, 'Radweg' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 5015, 'Strassenentwaesserung' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 6001, 'ZEB_Objekt' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7004, 'Teilbauwerk' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7008, 'Sachverhalt' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7014, 'Bruecke' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7015, 'Verkehrszeichenbruecke' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7016, 'Tunnel_Trogbauwerk' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7017, 'Laermschutzbauwerk' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7018, 'Stuetzbauwerk' )
INSERT INTO Art_Streckenobjekt_stat VALUES ( 7019, 'sonstiges_Bauwerk' )
INSERT INTO Art_Streckenobjekt_stat VALUES (35001,'Arbeitsstelle_an_Strassen')
INSERT INTO Art_Streckenobjekt_stat VALUES (35002,'verkehrliche_Angaben_Arbeitsst')
INSERT INTO Art_Streckenobjekt_stat VALUES (35003,'Umleitung_Strecke')

CREATE TABLE Streckenobjekt_hist (
   Streckenobjekt_hist_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streckenobjekt_hist_ID) REFERENCES Streckenobjekt,
   FOREIGN KEY (Streckenobjekt_hist_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Streckenobjekt_hist
      INTEGER NOT NULL REFERENCES Art_Streckenobjekt_hist
)

CREATE TABLE Art_Streckenobjekt_hist (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(38) NOT NULL
)

INSERT INTO Art_Streckenobjekt_hist VALUES ( 1060, 'Block' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 1072, 'Strassel_auf_Abschn_o_Ast' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 2030, 'OD_FS' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 2032, 'Widmung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4001, 'Schicht' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4005, 'Querschnittstreifen' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4008, 'Bauklasse_Oberbau' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4009, 'Bauweise_Oberbau' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4010, 'Regelquerschnitt' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4011, 'Bahnigkeit' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4013, 'Fahrbahnlaengsneigung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4014, 'Fahrbahnquerneigung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 4021, 'Hindernis' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5003, 'Nebenanlage' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5005, 'Rastanlage_nicht_bew' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5006, 'Rastanlage_bew' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5007, 'Nebenbetrieb' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5008, 'Leitung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5012, 'Markierung' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 5014, 'Schutzplanke' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 12001, 'automat_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 12015, 'abgeleitete_Dauerzaehlstelle' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 17006, 'raeuml_Gueltigkeitsbereich_MZ' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 20010, 'SB_Wirkungsbereiche' )
INSERT INTO Art_Streckenobjekt_hist VALUES ( 21038, 'raeumlicher_Gueltigkeitsber' )

CREATE TABLE Strecke (
   Strecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strecke_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Strecke_ID) REFERENCES Netzbereichskomponente,
   FOREIGN KEY (Strecke_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Strecke__entlang_Teilabschnitt (
   Strecke
      INTEGER NOT NULL REFERENCES Strecke,
   Position
      INTEGER NOT NULL,
   PRIMARY KEY ( Strecke , Position ),
   auf_Abschnitt_oder_Ast
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt,
   Station_1
      REAL NOT NULL, -- Kilometer
   Abstand_zur_Bestandsachse_1
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_1
      REAL, -- Meter
   Station_2
      REAL NOT NULL, -- Kilometer
   Abstand_zur_Bestandsachse_2
      REAL, -- Meter
   Abstand_z_Fahrbahnoberkante_2
      REAL -- Meter
)

CREATE TABLE Teilnetzkomponente (
   Teilnetzkomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Teilnetzkomponente
      INTEGER NOT NULL REFERENCES Art_Teilnetzkomponente
)

CREATE TABLE Art_Teilnetzkomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(15) NOT NULL
)

INSERT INTO Art_Teilnetzkomponente VALUES ( 1054, 'Teilnetz' )
INSERT INTO Art_Teilnetzkomponente VALUES ( 1056, 'Route' )
INSERT INTO Art_Teilnetzkomponente VALUES ( 1057, 'Strassenelement' )

CREATE TABLE Teilnetz (
   Teilnetz_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilnetz_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Teilnetz_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Teilnetz_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennzeichen_Teilnetz
      VARCHAR(6),
   Beschreibung_Teilnetz
      VARCHAR(60)
)

CREATE TABLE Teilnetz__enthaelt_Komponente (
   Teilnetz
      INTEGER NOT NULL REFERENCES Teilnetz,
   Teilnetzkomponente
      INTEGER NOT NULL REFERENCES Teilnetzkomponente
)

CREATE TABLE Routenkomponente (
   Routenkomponente_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Routenkomponente
      INTEGER NOT NULL REFERENCES Art_Routenkomponente
)

CREATE TABLE Art_Routenkomponente (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(15) NOT NULL
)

INSERT INTO Art_Routenkomponente VALUES ( 1056, 'Route' )
INSERT INTO Art_Routenkomponente VALUES ( 1057, 'Strassenelement' )

CREATE TABLE Routenkomp__hat_Vorgaenger (
   Routenkomponente
      INTEGER NOT NULL REFERENCES Routenkomponente,
   Routenkomponente_2
      INTEGER NOT NULL REFERENCES Routenkomponente
)

CREATE TABLE Route (
   Route_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Route_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Route_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Route_ID) REFERENCES Routenkomponente,
   FOREIGN KEY (Route_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Route__entlang_Komponente (
   Route
      INTEGER NOT NULL REFERENCES Route,
   Routenkomponente
      INTEGER NOT NULL REFERENCES Routenkomponente
)

CREATE TABLE Strassenelement (
   Strassenelement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Teilnetzkomponente,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Routenkomponente,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (Strassenelement_ID) REFERENCES Strassenelement_abstrakt,
   Strassenelement_ext
      CHAR(24),
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   GDF_ID
      VARCHAR(255),
   Verkehrsrichtung
      CHAR(1) REFERENCES Verkehrsrichtung_SE
)

CREATE TABLE Strassel__beginnt_bei_VP (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Verbindungspunkt_abstrakt
      INTEGER NOT NULL REFERENCES Verbindungspunkt_abstrakt
)

CREATE TABLE Strassenelement__endet_bei_VP (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Verbindungspunkt_abstrakt
      INTEGER NOT NULL REFERENCES Verbindungspunkt_abstrakt
)

CREATE TABLE Strassel__stat_auf_AoA (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Strassel_auf_Abschn_o_Ast
      INTEGER NOT NULL REFERENCES Strassel_auf_Abschn_o_Ast
)

CREATE TABLE Strassenelement__in_Nullpunkt (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Strassel__zw_Krzgsbereichen (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Abschnitt_oder_Ast_abstrakt
      INTEGER NOT NULL REFERENCES Abschnitt_oder_Ast_abstrakt
)

CREATE TABLE Strassel__i_Kreuzungsbereich (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Netzknoten_abstrakt
      INTEGER NOT NULL REFERENCES Netzknoten_abstrakt
)

CREATE TABLE Strassel__Beg_v_verb_Fahrbez (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Verbotene_Fahrbeziehung
      INTEGER NOT NULL REFERENCES Verbotene_Fahrbeziehung
)

CREATE TABLE Strassel__Mitte_v_verb_Fahrbez (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Verbotene_Fahrbeziehung
      INTEGER NOT NULL REFERENCES Verbotene_Fahrbeziehung
)

CREATE TABLE Strassel__Ende_v_verb_Fahrbez (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Verbotene_Fahrbeziehung
      INTEGER NOT NULL REFERENCES Verbotene_Fahrbeziehung
)

CREATE TABLE Strassel__v_Wegweiserinhalt (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Wegweiserinhalt
      INTEGER NOT NULL REFERENCES Statische_Beschilderung.Wegweiserinhalt
)

CREATE TABLE Strassel__n_Wegweiserinhalt (
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement,
   Wegweiserinhalt
      INTEGER NOT NULL REFERENCES Statische_Beschilderung.Wegweiserinhalt
)

CREATE TABLE Verkehrsrichtung_SE (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Verkehrsrichtung_SE VALUES ('R','Verkehrsrichtung von Von-VP nach Nach-VP')
INSERT INTO Verkehrsrichtung_SE VALUES ('G','Verkehrsrichtung von Nach-VP nach Von-VP')
INSERT INTO Verkehrsrichtung_SE VALUES ('B','In beiden Richtungen')

CREATE TABLE Strassenelement_abstrakt (
   Strassenelement_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Strassenelement_abstrakt
      INTEGER NOT NULL REFERENCES Art_Strassenelement_abstrakt
)

CREATE TABLE Art_Strassenelement_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

INSERT INTO Art_Strassenelement_abstrakt VALUES ( 1057, 'Strassenelement' )
INSERT INTO Art_Strassenelement_abstrakt VALUES ( 1068, 'Strassenelement_Symbol' )

CREATE TABLE Strassenelement_Symbol (
   Strassenelement_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strassenelement_Symbol_ID) REFERENCES Strassenelement_abstrakt,
   Kennung
      VARCHAR(24) NOT NULL
)

CREATE TABLE Strassel_auf_Abschn_o_Ast (
   Strassel_auf_Abschn_o_Ast_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strassel_auf_Abschn_o_Ast_ID) REFERENCES Streckenobjekt_hist
)

CREATE TABLE Verbindungspunkt (
   Verbindungspunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verbindungspunkt_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Verbindungspunkt_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (Verbindungspunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Verbindungspunkt_ID) REFERENCES Verbindungspunkt_abstrakt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Nummerierungsbezirk
      CHAR(4) NOT NULL, -- TK25_Blattnummer
   Nummer
      INTEGER NOT NULL,
   GDF_ID
      VARCHAR(255)
)

CREATE TABLE Verbindungspunkt__in_Nullpunkt (
   Verbindungspunkt
      INTEGER NOT NULL REFERENCES Verbindungspunkt,
   Nullpunkt_abstrakt
      INTEGER NOT NULL REFERENCES Nullpunkt_abstrakt
)

CREATE TABLE Verbindpkt__Beg_v_Strassel (
   Verbindungspunkt
      INTEGER NOT NULL REFERENCES Verbindungspunkt,
   Strassenelement_abstrakt
      INTEGER NOT NULL REFERENCES Strassenelement_abstrakt
)

CREATE TABLE Verbindpkt__Ende_v_Strassel (
   Verbindungspunkt
      INTEGER NOT NULL REFERENCES Verbindungspunkt,
   Strassenelement_abstrakt
      INTEGER NOT NULL REFERENCES Strassenelement_abstrakt
)

CREATE TABLE Verbindungspunkt_abstrakt (
   Verbindungspunkt_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Verbindungspunkt_abstrakt
      INTEGER NOT NULL REFERENCES Art_Verbindungspunkt_abstrakt
)

CREATE TABLE Art_Verbindungspunkt_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(23) NOT NULL
)

INSERT INTO Art_Verbindungspunkt_abstrakt VALUES ( 1069, 'Verbindungspunkt' )
INSERT INTO Art_Verbindungspunkt_abstrakt VALUES ( 1070, 'Verbindungspunkt_Symbol' )

CREATE TABLE Verbindungspunkt_Symbol (
   Verbindungspunkt_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verbindungspunkt_Symbol_ID) REFERENCES Verbindungspunkt_abstrakt,
   Kennung
      VARCHAR(12) NOT NULL
)

CREATE TABLE Verbotene_Fahrbeziehung (
   Verbotene_Fahrbeziehung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verbotene_Fahrbeziehung_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Verbotene_Fahrbeziehung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' )
)

CREATE TABLE Verb_Fahrbez__v_Strassel (
   Verbotene_Fahrbeziehung
      INTEGER NOT NULL REFERENCES Verbotene_Fahrbeziehung,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement
)

CREATE TABLE Verb_Fahrbez__ueber_Strassel (
   Verbotene_Fahrbeziehung
      INTEGER NOT NULL REFERENCES Verbotene_Fahrbeziehung,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement
)

CREATE TABLE Verb_Fahrbez__n_Strassel (
   Verbotene_Fahrbeziehung
      INTEGER NOT NULL REFERENCES Verbotene_Fahrbeziehung,
   Strassenelement
      INTEGER NOT NULL REFERENCES Strassenelement
)

CREATE TABLE Kilometrierung (
   Kilometrierung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kilometrierung_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Kilometrierung_ID) REFERENCES Punktobjekt_hist,
   Kilometrierung
      REAL NOT NULL, -- Kilometer
   Bezugsrichtung
      CHAR(1) REFERENCES Bezugsrichtung,
   historischer_Strassenname
      VARCHAR(14)
)

CREATE TABLE Betriebskilometer__in_Block (
   Betriebskilometer
      INTEGER NOT NULL REFERENCES Kilometrierung,
   Block
      INTEGER NOT NULL REFERENCES Block
)

CREATE TABLE Block (
   Block_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Block_ID) REFERENCES Administration.ASB_Objekt,
   FOREIGN KEY (Block_ID) REFERENCES Streckenobjekt_hist,
   Blocknummer
      VARCHAR(8) NOT NULL
)

CREATE TABLE Block__auf_Strasse (
   Block
      INTEGER NOT NULL REFERENCES Block,
   Strasse_abstrakt
      INTEGER NOT NULL REFERENCES Strasse_abstrakt
)

CREATE TABLE Block__Betriebskm_Anfang (
   Block
      INTEGER NOT NULL REFERENCES Block,
   Kilometrierung
      INTEGER NOT NULL REFERENCES Kilometrierung
)

CREATE TABLE Block__Betriebskilometer_Ende (
   Block
      INTEGER NOT NULL REFERENCES Block,
   Kilometrierung
      INTEGER NOT NULL REFERENCES Kilometrierung
)

CREATE TABLE Entwurfselement (
   Entwurfselement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_ID) REFERENCES Streckenobjekt_stat,
   Richtungsw_Tangente_am_Anfang
      REAL, -- Winkel
   beginnt_bei_Vermessungspunkt
      INTEGER NOT NULL,
   endet_bei_Vermessungspunkt
      INTEGER NOT NULL
)

CREATE TABLE Entwurfselement_Kreisbogen (
   Entwurfselement_Kreisbogen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Kreisbogen_ID) REFERENCES Entwurfselement,
   Radius
      REAL NOT NULL -- Meter
)

CREATE TABLE Entwurfselement_Klothoide (
   Entwurfselement_Klothoide_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Klothoide_ID) REFERENCES Entwurfselement,
   Radius_am_Anfang
      REAL NOT NULL, -- Meter
   Radius_am_Ende
      REAL, -- Meter
   Parameter
      REAL NOT NULL -- Meter
)

CREATE TABLE Entwurfselement_Gerade (
   Entwurfselement_Gerade_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwurfselement_Gerade_ID) REFERENCES Entwurfselement
)

